@@ -13,4 +13,6 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-from .constants import *
+
+PROJECT_NAME = "OctoBot-Channels"
+VERSION = "1.3.24"  # major.minor.revision
