@@ -17,7 +17,7 @@ from typing import Iterable
 
 from octobot_commons.logging.logging_util import get_logger
 
-from octobot_channels import CHANNEL_WILDCARD
+from octobot_channels.constants import CHANNEL_WILDCARD
 from octobot_channels.channels.channel_instances import ChannelInstances
 
 
