@@ -14,7 +14,4 @@
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
 
-PROJECT_NAME = "OctoBot-Channels"
-VERSION = "1.3.22"  # major.minor.revision
-
 CHANNEL_WILDCARD = "*"
